${name|h}

<%include file="/pageheader.html"/> <% import traceback from kaithem.src import unitsofmeasure import urllib.parse def url(u): return urllib.parse.quote(u,safe='') specialKeys={ 'subclass', 'name', 'type' } %>

# Available Configurations

This page shows various configurations suggested by the device driver. Note that some devices may have multi step configuration. You may need to accept a config and then visit this page again with the extra info.

Before accepting these configs you may edit them.

% for c in data:

## ${c|h}

### Basic

Device Type |
Device Name |
Store settings in Module(blank=store in main devices list) |
Resource Name(blank=use device name) |

### Device Specific

%for i in sorted([i for i in data[c].keys() if not i in specialKeys ] ): %if not i.startswith("kaithem.") and not i.startswith("temp.kaithem."):
${i|h} | %if obj and obj.config_properties.get(i,{}).get("secret",False): %else: %endif
%else:
${i|h} | %if obj and obj.config_properties.get(i,{}).get("secret",False): %else: %endif
%endif %endfor

%endfor <%include file="/pagefooter.html"/>